%define anolis_release 4

%bcond_without check

%global goipath github.com/containerd/containerd

Name:           containerd
Version:        1.6.20
Release:        %{anolis_release}%{?dist}
Summary:        Open and reliable container runtime
License:        ASL 2.0
URL:            https://github.com/containerd/containerd
Source0:        https://github.com/containerd/containerd/archive/refs/tags/v%{version}.tar.gz
Source1:        containerd.service
Source2:        containerd.toml

BuildRequires:  btrfs-progs-devel systemd-rpm-macros go-md2man
Requires:       runc

%gometa

%description
Containerd is an industry-standard container runtime with an emphasis on
simplicity, robustness and portability. It is available as a daemon for Linux
and Windows, which can manage the complete container lifecycle of its host
system: image transfer and storage, container execution and supervision,
low-level storage and network attachments, etc.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%gopkg

%prep
%goprep -k
# Used only for generation:
rm -rf cmd/protoc-gen-gogoctrd

%build
export LDFLAGS="-X %{goipath}/version.Version=%{version} "
for cmd in cmd/* ; do
  %gobuild -o %{gobuilddir}/bin/$(basename $cmd) %{goipath}/$cmd
done
mkdir _man
go-md2man -in docs/man/containerd-config.8.md -out _man/containerd-config.8
go-md2man -in docs/man/containerd-config.toml.5.md -out _man/containerd-config.toml.5
%{gobuilddir}/bin/gen-manpages containerd.8 _man
%{gobuilddir}/bin/gen-manpages ctr.8 _man
rm %{gobuilddir}/bin/gen-manpages

%install
mkdir -p %{buildroot}%{_bindir}
install -m 0755 -vp %{gobuilddir}/bin/* %{buildroot}%{_bindir}/
for file in containerd.8 containerd-config.8 ctr.8 containerd-config.toml.5; do
    if [ $file == "containerd-config.toml.5" ]; then
        install -D -p -m 0644 _man/$file %{buildroot}%{_mandir}/man5/$file
    else
        install -D -p -m 0644 _man/$file %{buildroot}%{_mandir}/man8/$file
    fi
done
install -D -p -m 0644 %{S:1} %{buildroot}%{_unitdir}/containerd.service
install -D -p -m 0644 %{S:2} %{buildroot}%{_sysconfdir}/containerd/config.toml

%post
%systemd_post containerd.service

%preun
%systemd_preun containerd.service

%postun
%systemd_postun_with_restart containerd.service

%if %{with check}
%check
%gocheck -d pkg/cri/server -t integration
%endif

%generate_compatibility_deps

%files
%license LICENSE NOTICE
%{_bindir}/*
%dir %{abidir}
%{abidir}/*-option.list
%{_mandir}/man8/containerd.8*
%{_mandir}/man8/containerd-config.8*
%{_mandir}/man8/ctr.8*
%{_mandir}/man5/containerd-config.toml.5*
%{_unitdir}/containerd.service
%dir %{_sysconfdir}/containerd
%config(noreplace) %{_sysconfdir}/containerd/config.toml

%files doc
%doc README.md RELEASES.md docs ROADMAP.md SCOPE.md
%doc code-of-conduct.md BUILDING.md

%changelog
* Tue Apr 18 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.6.20-3
- Fix the wrong placement for `%gometa` macro

* Tue Apr 18 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.6.20-3
- Remove Windows platform releated patches

* Mon Apr 10 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.6.20-2
- Optimize the spec file

* Fri Apr 07 2023 Funda Wang <fundawang@yeah.net> - 1.6.20-1
- New version 1.6.20

* Tue Apr 04 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.6.19-2
- build with local vendor and do not provide devel subpackage

* Tue Mar 07 2023 yuanhui <yuanhui@linux.alibaba.com> - 1.6.19-1
- Update to v1.6.19
- Add abi and doc files

* Thu Mar 10 2022 Yuanhong Peng <yummypeng@linux.alibaba.com> - 1.5.9-1
- Init from upstream v1.5.9
